import axios from "axios";
import router from "@/js/router";
import { useAuthStore } from "@/js/contexts/auth/store";
import type { SnowflakeProps } from "@/js/plugins/snowflake";

const props: SnowflakeProps = JSON.parse(atob(window.snowflake));

const instance = axios.create({
  baseURL: props.app.url,
  headers: {
    "X-Requested-With": "XMLHttpRequest",
  },
  withCredentials: true,
});

instance.interceptors.response.use(
  (response) => response,
  (error) => {
    if (error?.response?.status === 401) {
      router.push({ name: "login", query: { redirect: !["/login", "/", ""].includes(window.location.pathname) ? window.location.pathname : undefined } });
      useAuthStore().setAuthenticatedUser();
    }
    return Promise.reject(error);
  },
);

export default instance;
